// Generated by the protocol buffer compiler.  DO NOT EDIT!
// NO CHECKED-IN PROTOBUF GENCODE
// source: dynamic_partitions_device_info.proto
// Protobuf C++ Version: 7.35.0

#include "dynamic_partitions_device_info.pb.h"

#include <algorithm>
#include <type_traits>
#include "google/protobuf/io/coded_stream.h"
#include "google/protobuf/generated_message_tctable_impl.h"
#include "google/protobuf/internal_visibility.h"
#include "google/protobuf/extension_set.h"
#include "google/protobuf/generated_message_util.h"
#include "google/protobuf/wire_format_lite.h"
#include "google/protobuf/descriptor.h"
#include "google/protobuf/generated_message_reflection.h"
#include "google/protobuf/reflection_ops.h"
#include "google/protobuf/wire_format.h"
// @@protoc_insertion_point(includes)

// Must be included last.
#include "google/protobuf/port_def.inc"
PROTOBUF_PRAGMA_INIT_SEG
namespace _pb = ::google::protobuf;
namespace _pbi = ::google::protobuf::internal;
namespace _fl = ::google::protobuf::internal::field_layout;
#ifdef PROTOBUF_MESSAGE_GLOBALS
namespace {
PROTOBUF_CONSTINIT ::google::protobuf::internal::ReflectionData
    file_reflection_data[] = {
        // ::android::DynamicPartitionsDeviceInfoProto_Partition
        {&::_pbi::kDescriptorMethods, &::descriptor_table_dynamic_5fpartitions_5fdevice_5finfo_2eproto, /* tracker*/ nullptr,},
        // ::android::DynamicPartitionsDeviceInfoProto_Group
        {&::_pbi::kDescriptorMethods, &::descriptor_table_dynamic_5fpartitions_5fdevice_5finfo_2eproto, /* tracker*/ nullptr,},
        // ::android::DynamicPartitionsDeviceInfoProto_BlockDevice
        {&::_pbi::kDescriptorMethods, &::descriptor_table_dynamic_5fpartitions_5fdevice_5finfo_2eproto, /* tracker*/ nullptr,},
        // ::android::DynamicPartitionsDeviceInfoProto_SuperDevice
        {&::_pbi::kDescriptorMethods, &::descriptor_table_dynamic_5fpartitions_5fdevice_5finfo_2eproto, /* tracker*/ nullptr,},
        // ::android::DynamicPartitionsDeviceInfoProto
        {&::_pbi::kDescriptorMethods, &::descriptor_table_dynamic_5fpartitions_5fdevice_5finfo_2eproto, /* tracker*/ nullptr,},
};
}  // namespace
#endif
namespace android {
class DynamicPartitionsDeviceInfoProto_SuperDevice::_Internal {
 public:
  using HasBits = decltype(::std::declval<DynamicPartitionsDeviceInfoProto_SuperDevice>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_SuperDevice, _impl_._has_bits_);
};

constexpr DynamicPartitionsDeviceInfoProto_SuperDevice::ParseTableT_ DynamicPartitionsDeviceInfoProto_SuperDevice::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_SuperDevice, _impl_._has_bits_),
      0, // no _extensions_
      3, 24,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967288,  // skipmap
      offsetof(ParseTableT_, field_entries),
      3,  // num_field_entries
      0,  // num_aux_entries
      offsetof(ParseTableT_, field_names),  // no aux_entries
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::android::DynamicPartitionsDeviceInfoProto_SuperDevice>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      {::_pbi::TcParser::MiniParse, {}},
      // string name = 1;
      {::_pbi::TcParser::FastUS1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_SuperDevice, _impl_.name_)}},
      // uint64 used_size = 2 [json_name = "used_size"];
      {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(DynamicPartitionsDeviceInfoProto_SuperDevice, _impl_.used_size_), 1>(),
       {16, 1, 0,
        PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_SuperDevice, _impl_.used_size_)}},
      // uint64 total_size = 3 [json_name = "total_size"];
      {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(DynamicPartitionsDeviceInfoProto_SuperDevice, _impl_.total_size_), 2>(),
       {24, 2, 0,
        PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_SuperDevice, _impl_.total_size_)}},
    }}, {{
      65535, 65535
    }}, {{
      // string name = 1;
      {PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_SuperDevice, _impl_.name_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // uint64 used_size = 2 [json_name = "used_size"];
      {PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_SuperDevice, _impl_.used_size_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
      // uint64 total_size = 3 [json_name = "total_size"];
      {PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_SuperDevice, _impl_.total_size_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    }},
    // no aux_entries
    {{
      "\64\4\0\0\0\0\0\0"
      "android.DynamicPartitionsDeviceInfoProto.SuperDevice"
      "name"
    }},
  };
}


inline constexpr DynamicPartitionsDeviceInfoProto_SuperDevice::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        name_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        used_size_{::uint64_t{0u}},
        total_size_{::uint64_t{0u}} {}

template <typename>
constexpr DynamicPartitionsDeviceInfoProto_SuperDevice::DynamicPartitionsDeviceInfoProto_SuperDevice(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL DynamicPartitionsDeviceInfoProto_SuperDevice::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) DynamicPartitionsDeviceInfoProto_SuperDevice(arena);
}
constexpr auto DynamicPartitionsDeviceInfoProto_SuperDevice::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(DynamicPartitionsDeviceInfoProto_SuperDevice), alignof(DynamicPartitionsDeviceInfoProto_SuperDevice));
}
constexpr auto DynamicPartitionsDeviceInfoProto_SuperDevice::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &DynamicPartitionsDeviceInfoProto_SuperDevice::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<DynamicPartitionsDeviceInfoProto_SuperDevice>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &DynamicPartitionsDeviceInfoProto_SuperDevice::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<DynamicPartitionsDeviceInfoProto_SuperDevice>(), &DynamicPartitionsDeviceInfoProto_SuperDevice::ByteSizeLong,
              &DynamicPartitionsDeviceInfoProto_SuperDevice::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_SuperDevice, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[3],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_dynamic_5fpartitions_5fdevice_5finfo_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct DynamicPartitionsDeviceInfoProto_SuperDeviceGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr DynamicPartitionsDeviceInfoProto_SuperDeviceGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 DynamicPartitionsDeviceInfoProto_SuperDevice_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(DynamicPartitionsDeviceInfoProto_SuperDevice::InternalGenerateClassData_(
            _default, &DynamicPartitionsDeviceInfoProto_SuperDevice_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<DynamicPartitionsDeviceInfoProto_SuperDevice>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~DynamicPartitionsDeviceInfoProto_SuperDeviceGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) DynamicPartitionsDeviceInfoProto_SuperDevice _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<DynamicPartitionsDeviceInfoProto_SuperDevice>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_SuperDeviceGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST DynamicPartitionsDeviceInfoProto_SuperDeviceGlobalsTypeInternal DynamicPartitionsDeviceInfoProto_SuperDevice_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* DynamicPartitionsDeviceInfoProto_SuperDevice_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return DynamicPartitionsDeviceInfoProto_SuperDevice_globals_.GetClassData();
#else
  return DynamicPartitionsDeviceInfoProto_SuperDevice_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class DynamicPartitionsDeviceInfoProto_Partition::_Internal {
 public:
  using HasBits = decltype(::std::declval<DynamicPartitionsDeviceInfoProto_Partition>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_Partition, _impl_._has_bits_);
};

constexpr DynamicPartitionsDeviceInfoProto_Partition::ParseTableT_ DynamicPartitionsDeviceInfoProto_Partition::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_Partition, _impl_._has_bits_),
      0, // no _extensions_
      7, 56,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967168,  // skipmap
      offsetof(ParseTableT_, field_entries),
      7,  // num_field_entries
      0,  // num_aux_entries
      offsetof(ParseTableT_, field_names),  // no aux_entries
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::android::DynamicPartitionsDeviceInfoProto_Partition>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      {::_pbi::TcParser::MiniParse, {}},
      // string name = 1;
      {::_pbi::TcParser::FastUS1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_Partition, _impl_.name_)}},
      // string group_name = 2 [json_name = "group_name"];
      {::_pbi::TcParser::FastUS1,
       {18, 1, 0,
        PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_Partition, _impl_.group_name_)}},
      // bool is_dynamic = 3 [json_name = "is_dynamic"];
      {::_pbi::TcParser::SingularVarintNoZag1<bool, offsetof(DynamicPartitionsDeviceInfoProto_Partition, _impl_.is_dynamic_), 6>(),
       {24, 6, 0,
        PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_Partition, _impl_.is_dynamic_)}},
      // uint64 size = 4;
      {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(DynamicPartitionsDeviceInfoProto_Partition, _impl_.size_), 3>(),
       {32, 3, 0,
        PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_Partition, _impl_.size_)}},
      // uint64 fs_size = 5 [json_name = "fs_size"];
      {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(DynamicPartitionsDeviceInfoProto_Partition, _impl_.fs_size_), 4>(),
       {40, 4, 0,
        PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_Partition, _impl_.fs_size_)}},
      // uint64 fs_used = 6 [json_name = "fs_used"];
      {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(DynamicPartitionsDeviceInfoProto_Partition, _impl_.fs_used_), 5>(),
       {48, 5, 0,
        PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_Partition, _impl_.fs_used_)}},
      // string fs_type = 7 [json_name = "fs_type"];
      {::_pbi::TcParser::FastUS1,
       {58, 2, 0,
        PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_Partition, _impl_.fs_type_)}},
    }}, {{
      65535, 65535
    }}, {{
      // string name = 1;
      {PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_Partition, _impl_.name_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string group_name = 2 [json_name = "group_name"];
      {PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_Partition, _impl_.group_name_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // bool is_dynamic = 3 [json_name = "is_dynamic"];
      {PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_Partition, _impl_.is_dynamic_), _Internal::kHasBitsOffset + 6, 0, (0 | ::_fl::kFcOptional | ::_fl::kBool)},
      // uint64 size = 4;
      {PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_Partition, _impl_.size_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
      // uint64 fs_size = 5 [json_name = "fs_size"];
      {PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_Partition, _impl_.fs_size_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
      // uint64 fs_used = 6 [json_name = "fs_used"];
      {PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_Partition, _impl_.fs_used_), _Internal::kHasBitsOffset + 5, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
      // string fs_type = 7 [json_name = "fs_type"];
      {PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_Partition, _impl_.fs_type_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    }},
    // no aux_entries
    {{
      "\62\4\12\0\0\0\0\7"
      "android.DynamicPartitionsDeviceInfoProto.Partition"
      "name"
      "group_name"
      "fs_type"
    }},
  };
}


inline constexpr DynamicPartitionsDeviceInfoProto_Partition::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        name_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        group_name_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        fs_type_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        size_{::uint64_t{0u}},
        fs_size_{::uint64_t{0u}},
        fs_used_{::uint64_t{0u}},
        is_dynamic_{false} {}

template <typename>
constexpr DynamicPartitionsDeviceInfoProto_Partition::DynamicPartitionsDeviceInfoProto_Partition(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL DynamicPartitionsDeviceInfoProto_Partition::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) DynamicPartitionsDeviceInfoProto_Partition(arena);
}
constexpr auto DynamicPartitionsDeviceInfoProto_Partition::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(DynamicPartitionsDeviceInfoProto_Partition), alignof(DynamicPartitionsDeviceInfoProto_Partition));
}
constexpr auto DynamicPartitionsDeviceInfoProto_Partition::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &DynamicPartitionsDeviceInfoProto_Partition::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<DynamicPartitionsDeviceInfoProto_Partition>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &DynamicPartitionsDeviceInfoProto_Partition::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<DynamicPartitionsDeviceInfoProto_Partition>(), &DynamicPartitionsDeviceInfoProto_Partition::ByteSizeLong,
              &DynamicPartitionsDeviceInfoProto_Partition::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_Partition, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[0],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_dynamic_5fpartitions_5fdevice_5finfo_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct DynamicPartitionsDeviceInfoProto_PartitionGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr DynamicPartitionsDeviceInfoProto_PartitionGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 DynamicPartitionsDeviceInfoProto_Partition_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(DynamicPartitionsDeviceInfoProto_Partition::InternalGenerateClassData_(
            _default, &DynamicPartitionsDeviceInfoProto_Partition_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<DynamicPartitionsDeviceInfoProto_Partition>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~DynamicPartitionsDeviceInfoProto_PartitionGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) DynamicPartitionsDeviceInfoProto_Partition _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<DynamicPartitionsDeviceInfoProto_Partition>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_PartitionGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST DynamicPartitionsDeviceInfoProto_PartitionGlobalsTypeInternal DynamicPartitionsDeviceInfoProto_Partition_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* DynamicPartitionsDeviceInfoProto_Partition_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return DynamicPartitionsDeviceInfoProto_Partition_globals_.GetClassData();
#else
  return DynamicPartitionsDeviceInfoProto_Partition_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class DynamicPartitionsDeviceInfoProto_Group::_Internal {
 public:
  using HasBits = decltype(::std::declval<DynamicPartitionsDeviceInfoProto_Group>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_Group, _impl_._has_bits_);
};

constexpr DynamicPartitionsDeviceInfoProto_Group::ParseTableT_ DynamicPartitionsDeviceInfoProto_Group::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_Group, _impl_._has_bits_),
      0, // no _extensions_
      2, 8,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967292,  // skipmap
      offsetof(ParseTableT_, field_entries),
      2,  // num_field_entries
      0,  // num_aux_entries
      offsetof(ParseTableT_, field_names),  // no aux_entries
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::android::DynamicPartitionsDeviceInfoProto_Group>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      // uint64 maximum_size = 2 [json_name = "maximum_size"];
      {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(DynamicPartitionsDeviceInfoProto_Group, _impl_.maximum_size_), 1>(),
       {16, 1, 0,
        PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_Group, _impl_.maximum_size_)}},
      // string name = 1;
      {::_pbi::TcParser::FastUS1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_Group, _impl_.name_)}},
    }}, {{
      65535, 65535
    }}, {{
      // string name = 1;
      {PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_Group, _impl_.name_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // uint64 maximum_size = 2 [json_name = "maximum_size"];
      {PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_Group, _impl_.maximum_size_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    }},
    // no aux_entries
    {{
      "\56\4\0\0\0\0\0\0"
      "android.DynamicPartitionsDeviceInfoProto.Group"
      "name"
    }},
  };
}


inline constexpr DynamicPartitionsDeviceInfoProto_Group::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        name_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        maximum_size_{::uint64_t{0u}} {}

template <typename>
constexpr DynamicPartitionsDeviceInfoProto_Group::DynamicPartitionsDeviceInfoProto_Group(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL DynamicPartitionsDeviceInfoProto_Group::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) DynamicPartitionsDeviceInfoProto_Group(arena);
}
constexpr auto DynamicPartitionsDeviceInfoProto_Group::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(DynamicPartitionsDeviceInfoProto_Group), alignof(DynamicPartitionsDeviceInfoProto_Group));
}
constexpr auto DynamicPartitionsDeviceInfoProto_Group::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &DynamicPartitionsDeviceInfoProto_Group::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<DynamicPartitionsDeviceInfoProto_Group>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &DynamicPartitionsDeviceInfoProto_Group::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<DynamicPartitionsDeviceInfoProto_Group>(), &DynamicPartitionsDeviceInfoProto_Group::ByteSizeLong,
              &DynamicPartitionsDeviceInfoProto_Group::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_Group, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[1],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_dynamic_5fpartitions_5fdevice_5finfo_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct DynamicPartitionsDeviceInfoProto_GroupGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr DynamicPartitionsDeviceInfoProto_GroupGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 DynamicPartitionsDeviceInfoProto_Group_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(DynamicPartitionsDeviceInfoProto_Group::InternalGenerateClassData_(
            _default, &DynamicPartitionsDeviceInfoProto_Group_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<DynamicPartitionsDeviceInfoProto_Group>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~DynamicPartitionsDeviceInfoProto_GroupGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) DynamicPartitionsDeviceInfoProto_Group _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<DynamicPartitionsDeviceInfoProto_Group>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_GroupGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST DynamicPartitionsDeviceInfoProto_GroupGlobalsTypeInternal DynamicPartitionsDeviceInfoProto_Group_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* DynamicPartitionsDeviceInfoProto_Group_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return DynamicPartitionsDeviceInfoProto_Group_globals_.GetClassData();
#else
  return DynamicPartitionsDeviceInfoProto_Group_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class DynamicPartitionsDeviceInfoProto_BlockDevice::_Internal {
 public:
  using HasBits = decltype(::std::declval<DynamicPartitionsDeviceInfoProto_BlockDevice>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_BlockDevice, _impl_._has_bits_);
};

constexpr DynamicPartitionsDeviceInfoProto_BlockDevice::ParseTableT_ DynamicPartitionsDeviceInfoProto_BlockDevice::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_BlockDevice, _impl_._has_bits_),
      0, // no _extensions_
      5, 56,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967264,  // skipmap
      offsetof(ParseTableT_, field_entries),
      5,  // num_field_entries
      0,  // num_aux_entries
      offsetof(ParseTableT_, field_names),  // no aux_entries
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::android::DynamicPartitionsDeviceInfoProto_BlockDevice>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      {::_pbi::TcParser::MiniParse, {}},
      // string name = 1;
      {::_pbi::TcParser::FastUS1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_BlockDevice, _impl_.name_)}},
      // uint64 size = 2;
      {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(DynamicPartitionsDeviceInfoProto_BlockDevice, _impl_.size_), 1>(),
       {16, 1, 0,
        PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_BlockDevice, _impl_.size_)}},
      // uint64 block_size = 3 [json_name = "block_size"];
      {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(DynamicPartitionsDeviceInfoProto_BlockDevice, _impl_.block_size_), 2>(),
       {24, 2, 0,
        PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_BlockDevice, _impl_.block_size_)}},
      // uint64 alignment = 4;
      {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(DynamicPartitionsDeviceInfoProto_BlockDevice, _impl_.alignment_), 3>(),
       {32, 3, 0,
        PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_BlockDevice, _impl_.alignment_)}},
      // uint64 alignment_offset = 5 [json_name = "alignment_offset"];
      {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(DynamicPartitionsDeviceInfoProto_BlockDevice, _impl_.alignment_offset_), 4>(),
       {40, 4, 0,
        PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_BlockDevice, _impl_.alignment_offset_)}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
    }}, {{
      65535, 65535
    }}, {{
      // string name = 1;
      {PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_BlockDevice, _impl_.name_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // uint64 size = 2;
      {PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_BlockDevice, _impl_.size_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
      // uint64 block_size = 3 [json_name = "block_size"];
      {PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_BlockDevice, _impl_.block_size_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
      // uint64 alignment = 4;
      {PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_BlockDevice, _impl_.alignment_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
      // uint64 alignment_offset = 5 [json_name = "alignment_offset"];
      {PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_BlockDevice, _impl_.alignment_offset_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    }},
    // no aux_entries
    {{
      "\64\4\0\0\0\0\0\0"
      "android.DynamicPartitionsDeviceInfoProto.BlockDevice"
      "name"
    }},
  };
}


inline constexpr DynamicPartitionsDeviceInfoProto_BlockDevice::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        name_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        size_{::uint64_t{0u}},
        block_size_{::uint64_t{0u}},
        alignment_{::uint64_t{0u}},
        alignment_offset_{::uint64_t{0u}} {}

template <typename>
constexpr DynamicPartitionsDeviceInfoProto_BlockDevice::DynamicPartitionsDeviceInfoProto_BlockDevice(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL DynamicPartitionsDeviceInfoProto_BlockDevice::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) DynamicPartitionsDeviceInfoProto_BlockDevice(arena);
}
constexpr auto DynamicPartitionsDeviceInfoProto_BlockDevice::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(DynamicPartitionsDeviceInfoProto_BlockDevice), alignof(DynamicPartitionsDeviceInfoProto_BlockDevice));
}
constexpr auto DynamicPartitionsDeviceInfoProto_BlockDevice::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &DynamicPartitionsDeviceInfoProto_BlockDevice::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<DynamicPartitionsDeviceInfoProto_BlockDevice>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &DynamicPartitionsDeviceInfoProto_BlockDevice::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<DynamicPartitionsDeviceInfoProto_BlockDevice>(), &DynamicPartitionsDeviceInfoProto_BlockDevice::ByteSizeLong,
              &DynamicPartitionsDeviceInfoProto_BlockDevice::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_BlockDevice, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[2],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_dynamic_5fpartitions_5fdevice_5finfo_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct DynamicPartitionsDeviceInfoProto_BlockDeviceGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr DynamicPartitionsDeviceInfoProto_BlockDeviceGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 DynamicPartitionsDeviceInfoProto_BlockDevice_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(DynamicPartitionsDeviceInfoProto_BlockDevice::InternalGenerateClassData_(
            _default, &DynamicPartitionsDeviceInfoProto_BlockDevice_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<DynamicPartitionsDeviceInfoProto_BlockDevice>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~DynamicPartitionsDeviceInfoProto_BlockDeviceGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) DynamicPartitionsDeviceInfoProto_BlockDevice _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<DynamicPartitionsDeviceInfoProto_BlockDevice>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_BlockDeviceGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST DynamicPartitionsDeviceInfoProto_BlockDeviceGlobalsTypeInternal DynamicPartitionsDeviceInfoProto_BlockDevice_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* DynamicPartitionsDeviceInfoProto_BlockDevice_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return DynamicPartitionsDeviceInfoProto_BlockDevice_globals_.GetClassData();
#else
  return DynamicPartitionsDeviceInfoProto_BlockDevice_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class DynamicPartitionsDeviceInfoProto::_Internal {
 public:
  using HasBits = decltype(::std::declval<DynamicPartitionsDeviceInfoProto>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto, _impl_._has_bits_);
};

constexpr DynamicPartitionsDeviceInfoProto::ParseTableT_ DynamicPartitionsDeviceInfoProto::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto, _impl_._has_bits_),
      0, // no _extensions_
      6, 56,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967232,  // skipmap
      offsetof(ParseTableT_, field_entries),
      6,  // num_field_entries
      4,  // num_aux_entries
      offsetof(ParseTableT_, aux_entries),
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::android::DynamicPartitionsDeviceInfoProto>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      {::_pbi::TcParser::MiniParse, {}},
      // bool enabled = 1;
      {::_pbi::TcParser::SingularVarintNoZag1<bool, offsetof(DynamicPartitionsDeviceInfoProto, _impl_.enabled_), 4>(),
       {8, 4, 0,
        PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto, _impl_.enabled_)}},
      // bool retrofit = 2;
      {::_pbi::TcParser::SingularVarintNoZag1<bool, offsetof(DynamicPartitionsDeviceInfoProto, _impl_.retrofit_), 5>(),
       {16, 5, 0,
        PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto, _impl_.retrofit_)}},
      // repeated .android.DynamicPartitionsDeviceInfoProto.Partition partitions = 3;
      {::_pbi::TcParser::FastMtR1,
       {26, 0, 0,
        PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto, _impl_.partitions_)}},
      // repeated .android.DynamicPartitionsDeviceInfoProto.Group groups = 4;
      {::_pbi::TcParser::FastMtR1,
       {34, 1, 1,
        PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto, _impl_.groups_)}},
      // repeated .android.DynamicPartitionsDeviceInfoProto.BlockDevice block_devices = 5 [json_name = "block_devices"];
      {::_pbi::TcParser::FastMtR1,
       {42, 2, 2,
        PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto, _impl_.block_devices_)}},
      // .android.DynamicPartitionsDeviceInfoProto.SuperDevice super_device = 6 [json_name = "super_device"];
      {::_pbi::TcParser::FastMtS1,
       {50, 3, 3,
        PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto, _impl_.super_device_)}},
      {::_pbi::TcParser::MiniParse, {}},
    }}, {{
      65535, 65535
    }}, {{
      // bool enabled = 1;
      {PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto, _impl_.enabled_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kBool)},
      // bool retrofit = 2;
      {PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto, _impl_.retrofit_), _Internal::kHasBitsOffset + 5, 0, (0 | ::_fl::kFcOptional | ::_fl::kBool)},
      // repeated .android.DynamicPartitionsDeviceInfoProto.Partition partitions = 3;
      {PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto, _impl_.partitions_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcRepeated | ::_fl::kMessage | ::_fl::kTvTable)},
      // repeated .android.DynamicPartitionsDeviceInfoProto.Group groups = 4;
      {PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto, _impl_.groups_), _Internal::kHasBitsOffset + 1, 1, (0 | ::_fl::kFcRepeated | ::_fl::kMessage | ::_fl::kTvTable)},
      // repeated .android.DynamicPartitionsDeviceInfoProto.BlockDevice block_devices = 5 [json_name = "block_devices"];
      {PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto, _impl_.block_devices_), _Internal::kHasBitsOffset + 2, 2, (0 | ::_fl::kFcRepeated | ::_fl::kMessage | ::_fl::kTvTable)},
      // .android.DynamicPartitionsDeviceInfoProto.SuperDevice super_device = 6 [json_name = "super_device"];
      {PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto, _impl_.super_device_), _Internal::kHasBitsOffset + 3, 3, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    }},
    {{
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::android::DynamicPartitionsDeviceInfoProto_Partition>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::android::DynamicPartitionsDeviceInfoProto_Partition_globals_},
        #endif
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::android::DynamicPartitionsDeviceInfoProto_Group>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::android::DynamicPartitionsDeviceInfoProto_Group_globals_},
        #endif
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::android::DynamicPartitionsDeviceInfoProto_BlockDevice>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::android::DynamicPartitionsDeviceInfoProto_BlockDevice_globals_},
        #endif
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::android::DynamicPartitionsDeviceInfoProto_SuperDevice>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::android::DynamicPartitionsDeviceInfoProto_SuperDevice_globals_},
        #endif
    }},
    {{
    }},
  };
}


inline constexpr DynamicPartitionsDeviceInfoProto::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        partitions_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::android::DynamicPartitionsDeviceInfoProto,
            PROTOBUF_FIELD_OFFSET(::android::DynamicPartitionsDeviceInfoProto, _impl_.partitions_)>()
         }
        ,
        groups_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::android::DynamicPartitionsDeviceInfoProto,
            PROTOBUF_FIELD_OFFSET(::android::DynamicPartitionsDeviceInfoProto, _impl_.groups_)>()
         }
        ,
        block_devices_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::android::DynamicPartitionsDeviceInfoProto,
            PROTOBUF_FIELD_OFFSET(::android::DynamicPartitionsDeviceInfoProto, _impl_.block_devices_)>()
         }
        ,
        super_device_{nullptr},
        enabled_{false},
        retrofit_{false} {}

template <typename>
constexpr DynamicPartitionsDeviceInfoProto::DynamicPartitionsDeviceInfoProto(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL DynamicPartitionsDeviceInfoProto::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) DynamicPartitionsDeviceInfoProto(arena);
}
constexpr auto DynamicPartitionsDeviceInfoProto::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(DynamicPartitionsDeviceInfoProto), alignof(DynamicPartitionsDeviceInfoProto));
}
constexpr auto DynamicPartitionsDeviceInfoProto::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &DynamicPartitionsDeviceInfoProto::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<DynamicPartitionsDeviceInfoProto>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &DynamicPartitionsDeviceInfoProto::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<DynamicPartitionsDeviceInfoProto>(), &DynamicPartitionsDeviceInfoProto::ByteSizeLong,
              &DynamicPartitionsDeviceInfoProto::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[4],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_dynamic_5fpartitions_5fdevice_5finfo_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct DynamicPartitionsDeviceInfoProtoGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr DynamicPartitionsDeviceInfoProtoGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 DynamicPartitionsDeviceInfoProto_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(DynamicPartitionsDeviceInfoProto::InternalGenerateClassData_(
            _default, &DynamicPartitionsDeviceInfoProto_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<DynamicPartitionsDeviceInfoProto>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~DynamicPartitionsDeviceInfoProtoGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) DynamicPartitionsDeviceInfoProto _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<DynamicPartitionsDeviceInfoProto>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProtoGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST DynamicPartitionsDeviceInfoProtoGlobalsTypeInternal DynamicPartitionsDeviceInfoProto_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* DynamicPartitionsDeviceInfoProto_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return DynamicPartitionsDeviceInfoProto_globals_.GetClassData();
#else
  return DynamicPartitionsDeviceInfoProto_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
}  // namespace android
static constexpr const ::_pb::EnumDescriptor* PROTOBUF_NONNULL* PROTOBUF_NULLABLE
    file_level_enum_descriptors_dynamic_5fpartitions_5fdevice_5finfo_2eproto = nullptr;
static constexpr const ::_pb::ServiceDescriptor* PROTOBUF_NONNULL* PROTOBUF_NULLABLE
    file_level_service_descriptors_dynamic_5fpartitions_5fdevice_5finfo_2eproto = nullptr;
const ::uint32_t
    TableStruct_dynamic_5fpartitions_5fdevice_5finfo_2eproto::offsets[] ABSL_ATTRIBUTE_SECTION_VARIABLE(
        protodesc_cold) = {
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::android::DynamicPartitionsDeviceInfoProto_Partition, _impl_._has_bits_),
        10, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::android::DynamicPartitionsDeviceInfoProto_Partition, _impl_.name_),
        PROTOBUF_FIELD_OFFSET(::android::DynamicPartitionsDeviceInfoProto_Partition, _impl_.group_name_),
        PROTOBUF_FIELD_OFFSET(::android::DynamicPartitionsDeviceInfoProto_Partition, _impl_.is_dynamic_),
        PROTOBUF_FIELD_OFFSET(::android::DynamicPartitionsDeviceInfoProto_Partition, _impl_.size_),
        PROTOBUF_FIELD_OFFSET(::android::DynamicPartitionsDeviceInfoProto_Partition, _impl_.fs_size_),
        PROTOBUF_FIELD_OFFSET(::android::DynamicPartitionsDeviceInfoProto_Partition, _impl_.fs_used_),
        PROTOBUF_FIELD_OFFSET(::android::DynamicPartitionsDeviceInfoProto_Partition, _impl_.fs_type_),
        0,
        1,
        6,
        3,
        4,
        5,
        2,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::android::DynamicPartitionsDeviceInfoProto_Group, _impl_._has_bits_),
        5, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::android::DynamicPartitionsDeviceInfoProto_Group, _impl_.name_),
        PROTOBUF_FIELD_OFFSET(::android::DynamicPartitionsDeviceInfoProto_Group, _impl_.maximum_size_),
        0,
        1,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::android::DynamicPartitionsDeviceInfoProto_BlockDevice, _impl_._has_bits_),
        8, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::android::DynamicPartitionsDeviceInfoProto_BlockDevice, _impl_.name_),
        PROTOBUF_FIELD_OFFSET(::android::DynamicPartitionsDeviceInfoProto_BlockDevice, _impl_.size_),
        PROTOBUF_FIELD_OFFSET(::android::DynamicPartitionsDeviceInfoProto_BlockDevice, _impl_.block_size_),
        PROTOBUF_FIELD_OFFSET(::android::DynamicPartitionsDeviceInfoProto_BlockDevice, _impl_.alignment_),
        PROTOBUF_FIELD_OFFSET(::android::DynamicPartitionsDeviceInfoProto_BlockDevice, _impl_.alignment_offset_),
        0,
        1,
        2,
        3,
        4,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::android::DynamicPartitionsDeviceInfoProto_SuperDevice, _impl_._has_bits_),
        6, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::android::DynamicPartitionsDeviceInfoProto_SuperDevice, _impl_.name_),
        PROTOBUF_FIELD_OFFSET(::android::DynamicPartitionsDeviceInfoProto_SuperDevice, _impl_.used_size_),
        PROTOBUF_FIELD_OFFSET(::android::DynamicPartitionsDeviceInfoProto_SuperDevice, _impl_.total_size_),
        0,
        1,
        2,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::android::DynamicPartitionsDeviceInfoProto, _impl_._has_bits_),
        9, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::android::DynamicPartitionsDeviceInfoProto, _impl_.enabled_),
        PROTOBUF_FIELD_OFFSET(::android::DynamicPartitionsDeviceInfoProto, _impl_.retrofit_),
        PROTOBUF_FIELD_OFFSET(::android::DynamicPartitionsDeviceInfoProto, _impl_.partitions_),
        PROTOBUF_FIELD_OFFSET(::android::DynamicPartitionsDeviceInfoProto, _impl_.groups_),
        PROTOBUF_FIELD_OFFSET(::android::DynamicPartitionsDeviceInfoProto, _impl_.block_devices_),
        PROTOBUF_FIELD_OFFSET(::android::DynamicPartitionsDeviceInfoProto, _impl_.super_device_),
        4,
        5,
        0,
        1,
        2,
        3,
};

static const ::_pbi::MigrationSchema
    schemas[] ABSL_ATTRIBUTE_SECTION_VARIABLE(protodesc_cold) = {
        {0, sizeof(::android::DynamicPartitionsDeviceInfoProto_Partition)},
        {17, sizeof(::android::DynamicPartitionsDeviceInfoProto_Group)},
        {24, sizeof(::android::DynamicPartitionsDeviceInfoProto_BlockDevice)},
        {37, sizeof(::android::DynamicPartitionsDeviceInfoProto_SuperDevice)},
        {46, sizeof(::android::DynamicPartitionsDeviceInfoProto)},
};
static const ::_pbi::MessageGlobalsBase* PROTOBUF_NONNULL const
    file_message_globals[] = {
        &::android::DynamicPartitionsDeviceInfoProto_Partition_globals_,
        &::android::DynamicPartitionsDeviceInfoProto_Group_globals_,
        &::android::DynamicPartitionsDeviceInfoProto_BlockDevice_globals_,
        &::android::DynamicPartitionsDeviceInfoProto_SuperDevice_globals_,
        &::android::DynamicPartitionsDeviceInfoProto_globals_,
};
const char descriptor_table_protodef_dynamic_5fpartitions_5fdevice_5finfo_2eproto[] ABSL_ATTRIBUTE_SECTION_VARIABLE(
    protodesc_cold) = {
    "\n$dynamic_partitions_device_info.proto\022\007"
    "android\"\340\006\n DynamicPartitionsDeviceInfoP"
    "roto\022\017\n\007enabled\030\001 \001(\010\022\020\n\010retrofit\030\002 \001(\010\022"
    "G\n\npartitions\030\003 \003(\01323.android.DynamicPar"
    "titionsDeviceInfoProto.Partition\022\?\n\006grou"
    "ps\030\004 \003(\0132/.android.DynamicPartitionsDevi"
    "ceInfoProto.Group\022[\n\rblock_devices\030\005 \003(\013"
    "25.android.DynamicPartitionsDeviceInfoPr"
    "oto.BlockDeviceR\rblock_devices\022Y\n\014super_"
    "device\030\006 \001(\01325.android.DynamicPartitions"
    "DeviceInfoProto.SuperDeviceR\014super_devic"
    "e\032\265\001\n\tPartition\022\014\n\004name\030\001 \001(\t\022\036\n\ngroup_n"
    "ame\030\002 \001(\tR\ngroup_name\022\036\n\nis_dynamic\030\003 \001("
    "\010R\nis_dynamic\022\014\n\004size\030\004 \001(\004\022\030\n\007fs_size\030\005"
    " \001(\004R\007fs_size\022\030\n\007fs_used\030\006 \001(\004R\007fs_used\022"
    "\030\n\007fs_type\030\007 \001(\tR\007fs_type\0329\n\005Group\022\014\n\004na"
    "me\030\001 \001(\t\022\"\n\014maximum_size\030\002 \001(\004R\014maximum_"
    "size\032\210\001\n\013BlockDevice\022\014\n\004name\030\001 \001(\t\022\014\n\004si"
    "ze\030\002 \001(\004\022\036\n\nblock_size\030\003 \001(\004R\nblock_size"
    "\022\021\n\talignment\030\004 \001(\004\022*\n\020alignment_offset\030"
    "\005 \001(\004R\020alignment_offset\032Y\n\013SuperDevice\022\014"
    "\n\004name\030\001 \001(\t\022\034\n\tused_size\030\002 \001(\004R\tused_si"
    "ze\022\036\n\ntotal_size\030\003 \001(\004R\ntotal_sizeb\006prot"
    "o3"
};
static ::absl::once_flag descriptor_table_dynamic_5fpartitions_5fdevice_5finfo_2eproto_once;
PROTOBUF_CONSTINIT const ::_pbi::DescriptorTable descriptor_table_dynamic_5fpartitions_5fdevice_5finfo_2eproto = {
    false,
    false,
    922,
    descriptor_table_protodef_dynamic_5fpartitions_5fdevice_5finfo_2eproto,
    "dynamic_partitions_device_info.proto",
    &descriptor_table_dynamic_5fpartitions_5fdevice_5finfo_2eproto_once,
    nullptr,
    0,
    5,
    schemas,
    file_message_globals,
    TableStruct_dynamic_5fpartitions_5fdevice_5finfo_2eproto::offsets,
    file_level_enum_descriptors_dynamic_5fpartitions_5fdevice_5finfo_2eproto,
    file_level_service_descriptors_dynamic_5fpartitions_5fdevice_5finfo_2eproto,
};
namespace android {
// ===================================================================

DynamicPartitionsDeviceInfoProto_Partition::DynamicPartitionsDeviceInfoProto_Partition(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, DynamicPartitionsDeviceInfoProto_Partition_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:android.DynamicPartitionsDeviceInfoProto.Partition)
}
PROTOBUF_NDEBUG_INLINE DynamicPartitionsDeviceInfoProto_Partition::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::android::DynamicPartitionsDeviceInfoProto_Partition& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        name_(arena, from.name_),
        group_name_(arena, from.group_name_),
        fs_type_(arena, from.fs_type_) {}

DynamicPartitionsDeviceInfoProto_Partition::DynamicPartitionsDeviceInfoProto_Partition(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const DynamicPartitionsDeviceInfoProto_Partition& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, DynamicPartitionsDeviceInfoProto_Partition_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  DynamicPartitionsDeviceInfoProto_Partition* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, size_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, size_),
           offsetof(Impl_, is_dynamic_) -
               offsetof(Impl_, size_) +
               sizeof(Impl_::is_dynamic_));

  // @@protoc_insertion_point(copy_constructor:android.DynamicPartitionsDeviceInfoProto.Partition)
}
PROTOBUF_NDEBUG_INLINE DynamicPartitionsDeviceInfoProto_Partition::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        name_(arena),
        group_name_(arena),
        fs_type_(arena) {}

inline void DynamicPartitionsDeviceInfoProto_Partition::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, size_),
           0,
           offsetof(Impl_, is_dynamic_) -
               offsetof(Impl_, size_) +
               sizeof(Impl_::is_dynamic_));
}
DynamicPartitionsDeviceInfoProto_Partition::~DynamicPartitionsDeviceInfoProto_Partition() {
  // @@protoc_insertion_point(destructor:android.DynamicPartitionsDeviceInfoProto.Partition)
  SharedDtor(*this);
}
inline void DynamicPartitionsDeviceInfoProto_Partition::SharedDtor(MessageLite& self) {
  DynamicPartitionsDeviceInfoProto_Partition& this_ = static_cast<DynamicPartitionsDeviceInfoProto_Partition&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.name_.Destroy();
  this_._impl_.group_name_.Destroy();
  this_._impl_.fs_type_.Destroy();
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull DynamicPartitionsDeviceInfoProto_Partition_class_data_ =
        DynamicPartitionsDeviceInfoProto_Partition::InternalGenerateClassData_(DynamicPartitionsDeviceInfoProto_Partition_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
DynamicPartitionsDeviceInfoProto_Partition::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&DynamicPartitionsDeviceInfoProto_Partition_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(DynamicPartitionsDeviceInfoProto_Partition_class_data_.tc_table);
  return DynamicPartitionsDeviceInfoProto_Partition_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
DynamicPartitionsDeviceInfoProto_Partition::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&DynamicPartitionsDeviceInfoProto_Partition_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&DynamicPartitionsDeviceInfoProto_Partition_globals_));
  return DynamicPartitionsDeviceInfoProto_Partition_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const DynamicPartitionsDeviceInfoProto_Partition::ParseTableT_
    DynamicPartitionsDeviceInfoProto_Partition::_table_ =
        DynamicPartitionsDeviceInfoProto_Partition::InternalGenerateParseTable_(DynamicPartitionsDeviceInfoProto_Partition_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void DynamicPartitionsDeviceInfoProto_Partition::Clear() {
// @@protoc_insertion_point(message_clear_start:android.DynamicPartitionsDeviceInfoProto.Partition)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.name_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _impl_.group_name_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      _impl_.fs_type_.ClearNonDefaultToEmpty();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00000078U)) {
    ::memset(&_impl_.size_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.is_dynamic_) -
        reinterpret_cast<char*>(&_impl_.size_)) + sizeof(_impl_.is_dynamic_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL DynamicPartitionsDeviceInfoProto_Partition::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const DynamicPartitionsDeviceInfoProto_Partition& this_ = static_cast<const DynamicPartitionsDeviceInfoProto_Partition&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL DynamicPartitionsDeviceInfoProto_Partition::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const DynamicPartitionsDeviceInfoProto_Partition& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:android.DynamicPartitionsDeviceInfoProto.Partition)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // string name = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_name().empty()) {
      const ::std::string& _s = this_._internal_name();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "android.DynamicPartitionsDeviceInfoProto.Partition.name");
      target = stream->WriteStringMaybeAliased(1, _s, target);
    }
  }

  // string group_name = 2 [json_name = "group_name"];
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    if (!this_._internal_group_name().empty()) {
      const ::std::string& _s = this_._internal_group_name();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "android.DynamicPartitionsDeviceInfoProto.Partition.group_name");
      target = stream->WriteStringMaybeAliased(2, _s, target);
    }
  }

  // bool is_dynamic = 3 [json_name = "is_dynamic"];
  if (CheckHasBit(cached_has_bits, 0x00000040U)) {
    if (this_._internal_is_dynamic() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteBoolToArray(
          3, this_._internal_is_dynamic(), target);
    }
  }

  // uint64 size = 4;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    if (this_._internal_size() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          4, this_._internal_size(), target);
    }
  }

  // uint64 fs_size = 5 [json_name = "fs_size"];
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    if (this_._internal_fs_size() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          5, this_._internal_fs_size(), target);
    }
  }

  // uint64 fs_used = 6 [json_name = "fs_used"];
  if (CheckHasBit(cached_has_bits, 0x00000020U)) {
    if (this_._internal_fs_used() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          6, this_._internal_fs_used(), target);
    }
  }

  // string fs_type = 7 [json_name = "fs_type"];
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    if (!this_._internal_fs_type().empty()) {
      const ::std::string& _s = this_._internal_fs_type();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "android.DynamicPartitionsDeviceInfoProto.Partition.fs_type");
      target = stream->WriteStringMaybeAliased(7, _s, target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:android.DynamicPartitionsDeviceInfoProto.Partition)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t DynamicPartitionsDeviceInfoProto_Partition::ByteSizeLong(const MessageLite& base) {
  const DynamicPartitionsDeviceInfoProto_Partition& this_ = static_cast<const DynamicPartitionsDeviceInfoProto_Partition&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t DynamicPartitionsDeviceInfoProto_Partition::ByteSizeLong() const {
  const DynamicPartitionsDeviceInfoProto_Partition& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:android.DynamicPartitionsDeviceInfoProto.Partition)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000007fU)) {
    // string name = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!this_._internal_name().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_name());
      }
    }
    // string group_name = 2 [json_name = "group_name"];
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!this_._internal_group_name().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_group_name());
      }
    }
    // string fs_type = 7 [json_name = "fs_type"];
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (!this_._internal_fs_type().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_fs_type());
      }
    }
    // uint64 size = 4;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (this_._internal_size() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_size());
      }
    }
    // uint64 fs_size = 5 [json_name = "fs_size"];
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (this_._internal_fs_size() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_fs_size());
      }
    }
    // uint64 fs_used = 6 [json_name = "fs_used"];
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (this_._internal_fs_used() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_fs_used());
      }
    }
    // bool is_dynamic = 3 [json_name = "is_dynamic"];
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (this_._internal_is_dynamic() != 0) {
        total_size += 2;
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void DynamicPartitionsDeviceInfoProto_Partition::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<DynamicPartitionsDeviceInfoProto_Partition*>(&to_msg);
  auto& from = static_cast<const DynamicPartitionsDeviceInfoProto_Partition&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:android.DynamicPartitionsDeviceInfoProto.Partition)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000007fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!from._internal_name().empty()) {
        _this->_internal_set_name(from._internal_name());
      } else {
        if (_this->_impl_.name_.IsDefault()) {
          _this->_internal_set_name("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!from._internal_group_name().empty()) {
        _this->_internal_set_group_name(from._internal_group_name());
      } else {
        if (_this->_impl_.group_name_.IsDefault()) {
          _this->_internal_set_group_name("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (!from._internal_fs_type().empty()) {
        _this->_internal_set_fs_type(from._internal_fs_type());
      } else {
        if (_this->_impl_.fs_type_.IsDefault()) {
          _this->_internal_set_fs_type("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (from._internal_size() != 0) {
        _this->_impl_.size_ = from._impl_.size_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (from._internal_fs_size() != 0) {
        _this->_impl_.fs_size_ = from._impl_.fs_size_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (from._internal_fs_used() != 0) {
        _this->_impl_.fs_used_ = from._impl_.fs_used_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (from._internal_is_dynamic() != 0) {
        _this->_impl_.is_dynamic_ = from._impl_.is_dynamic_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void DynamicPartitionsDeviceInfoProto_Partition::CopyFrom(const DynamicPartitionsDeviceInfoProto_Partition& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:android.DynamicPartitionsDeviceInfoProto.Partition)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void DynamicPartitionsDeviceInfoProto_Partition::InternalSwap(DynamicPartitionsDeviceInfoProto_Partition* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.name_, &other->_impl_.name_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.group_name_, &other->_impl_.group_name_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.fs_type_, &other->_impl_.fs_type_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_Partition, _impl_.is_dynamic_)
      + sizeof(DynamicPartitionsDeviceInfoProto_Partition::_impl_.is_dynamic_)
      - PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_Partition, _impl_.size_)>(
          reinterpret_cast<char*>(&_impl_.size_),
          reinterpret_cast<char*>(&other->_impl_.size_));
}

::google::protobuf::Metadata DynamicPartitionsDeviceInfoProto_Partition::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

DynamicPartitionsDeviceInfoProto_Group::DynamicPartitionsDeviceInfoProto_Group(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, DynamicPartitionsDeviceInfoProto_Group_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:android.DynamicPartitionsDeviceInfoProto.Group)
}
PROTOBUF_NDEBUG_INLINE DynamicPartitionsDeviceInfoProto_Group::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::android::DynamicPartitionsDeviceInfoProto_Group& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        name_(arena, from.name_) {}

DynamicPartitionsDeviceInfoProto_Group::DynamicPartitionsDeviceInfoProto_Group(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const DynamicPartitionsDeviceInfoProto_Group& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, DynamicPartitionsDeviceInfoProto_Group_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  DynamicPartitionsDeviceInfoProto_Group* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  _impl_.maximum_size_ = from._impl_.maximum_size_;

  // @@protoc_insertion_point(copy_constructor:android.DynamicPartitionsDeviceInfoProto.Group)
}
PROTOBUF_NDEBUG_INLINE DynamicPartitionsDeviceInfoProto_Group::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        name_(arena) {}

inline void DynamicPartitionsDeviceInfoProto_Group::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  _impl_.maximum_size_ = {};
}
DynamicPartitionsDeviceInfoProto_Group::~DynamicPartitionsDeviceInfoProto_Group() {
  // @@protoc_insertion_point(destructor:android.DynamicPartitionsDeviceInfoProto.Group)
  SharedDtor(*this);
}
inline void DynamicPartitionsDeviceInfoProto_Group::SharedDtor(MessageLite& self) {
  DynamicPartitionsDeviceInfoProto_Group& this_ = static_cast<DynamicPartitionsDeviceInfoProto_Group&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.name_.Destroy();
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull DynamicPartitionsDeviceInfoProto_Group_class_data_ =
        DynamicPartitionsDeviceInfoProto_Group::InternalGenerateClassData_(DynamicPartitionsDeviceInfoProto_Group_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
DynamicPartitionsDeviceInfoProto_Group::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&DynamicPartitionsDeviceInfoProto_Group_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(DynamicPartitionsDeviceInfoProto_Group_class_data_.tc_table);
  return DynamicPartitionsDeviceInfoProto_Group_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
DynamicPartitionsDeviceInfoProto_Group::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&DynamicPartitionsDeviceInfoProto_Group_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&DynamicPartitionsDeviceInfoProto_Group_globals_));
  return DynamicPartitionsDeviceInfoProto_Group_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const DynamicPartitionsDeviceInfoProto_Group::ParseTableT_
    DynamicPartitionsDeviceInfoProto_Group::_table_ =
        DynamicPartitionsDeviceInfoProto_Group::InternalGenerateParseTable_(DynamicPartitionsDeviceInfoProto_Group_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void DynamicPartitionsDeviceInfoProto_Group::Clear() {
// @@protoc_insertion_point(message_clear_start:android.DynamicPartitionsDeviceInfoProto.Group)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    _impl_.name_.ClearNonDefaultToEmpty();
  }
  _impl_.maximum_size_ = ::uint64_t{0u};
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL DynamicPartitionsDeviceInfoProto_Group::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const DynamicPartitionsDeviceInfoProto_Group& this_ = static_cast<const DynamicPartitionsDeviceInfoProto_Group&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL DynamicPartitionsDeviceInfoProto_Group::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const DynamicPartitionsDeviceInfoProto_Group& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:android.DynamicPartitionsDeviceInfoProto.Group)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // string name = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_name().empty()) {
      const ::std::string& _s = this_._internal_name();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "android.DynamicPartitionsDeviceInfoProto.Group.name");
      target = stream->WriteStringMaybeAliased(1, _s, target);
    }
  }

  // uint64 maximum_size = 2 [json_name = "maximum_size"];
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    if (this_._internal_maximum_size() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          2, this_._internal_maximum_size(), target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:android.DynamicPartitionsDeviceInfoProto.Group)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t DynamicPartitionsDeviceInfoProto_Group::ByteSizeLong(const MessageLite& base) {
  const DynamicPartitionsDeviceInfoProto_Group& this_ = static_cast<const DynamicPartitionsDeviceInfoProto_Group&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t DynamicPartitionsDeviceInfoProto_Group::ByteSizeLong() const {
  const DynamicPartitionsDeviceInfoProto_Group& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:android.DynamicPartitionsDeviceInfoProto.Group)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    // string name = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!this_._internal_name().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_name());
      }
    }
    // uint64 maximum_size = 2 [json_name = "maximum_size"];
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (this_._internal_maximum_size() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_maximum_size());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void DynamicPartitionsDeviceInfoProto_Group::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<DynamicPartitionsDeviceInfoProto_Group*>(&to_msg);
  auto& from = static_cast<const DynamicPartitionsDeviceInfoProto_Group&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:android.DynamicPartitionsDeviceInfoProto.Group)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!from._internal_name().empty()) {
        _this->_internal_set_name(from._internal_name());
      } else {
        if (_this->_impl_.name_.IsDefault()) {
          _this->_internal_set_name("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (from._internal_maximum_size() != 0) {
        _this->_impl_.maximum_size_ = from._impl_.maximum_size_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void DynamicPartitionsDeviceInfoProto_Group::CopyFrom(const DynamicPartitionsDeviceInfoProto_Group& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:android.DynamicPartitionsDeviceInfoProto.Group)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void DynamicPartitionsDeviceInfoProto_Group::InternalSwap(DynamicPartitionsDeviceInfoProto_Group* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.name_, &other->_impl_.name_, arena);
  swap(_impl_.maximum_size_, other->_impl_.maximum_size_);
}

::google::protobuf::Metadata DynamicPartitionsDeviceInfoProto_Group::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

DynamicPartitionsDeviceInfoProto_BlockDevice::DynamicPartitionsDeviceInfoProto_BlockDevice(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, DynamicPartitionsDeviceInfoProto_BlockDevice_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:android.DynamicPartitionsDeviceInfoProto.BlockDevice)
}
PROTOBUF_NDEBUG_INLINE DynamicPartitionsDeviceInfoProto_BlockDevice::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::android::DynamicPartitionsDeviceInfoProto_BlockDevice& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        name_(arena, from.name_) {}

DynamicPartitionsDeviceInfoProto_BlockDevice::DynamicPartitionsDeviceInfoProto_BlockDevice(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const DynamicPartitionsDeviceInfoProto_BlockDevice& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, DynamicPartitionsDeviceInfoProto_BlockDevice_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  DynamicPartitionsDeviceInfoProto_BlockDevice* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, size_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, size_),
           offsetof(Impl_, alignment_offset_) -
               offsetof(Impl_, size_) +
               sizeof(Impl_::alignment_offset_));

  // @@protoc_insertion_point(copy_constructor:android.DynamicPartitionsDeviceInfoProto.BlockDevice)
}
PROTOBUF_NDEBUG_INLINE DynamicPartitionsDeviceInfoProto_BlockDevice::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        name_(arena) {}

inline void DynamicPartitionsDeviceInfoProto_BlockDevice::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, size_),
           0,
           offsetof(Impl_, alignment_offset_) -
               offsetof(Impl_, size_) +
               sizeof(Impl_::alignment_offset_));
}
DynamicPartitionsDeviceInfoProto_BlockDevice::~DynamicPartitionsDeviceInfoProto_BlockDevice() {
  // @@protoc_insertion_point(destructor:android.DynamicPartitionsDeviceInfoProto.BlockDevice)
  SharedDtor(*this);
}
inline void DynamicPartitionsDeviceInfoProto_BlockDevice::SharedDtor(MessageLite& self) {
  DynamicPartitionsDeviceInfoProto_BlockDevice& this_ = static_cast<DynamicPartitionsDeviceInfoProto_BlockDevice&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.name_.Destroy();
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull DynamicPartitionsDeviceInfoProto_BlockDevice_class_data_ =
        DynamicPartitionsDeviceInfoProto_BlockDevice::InternalGenerateClassData_(DynamicPartitionsDeviceInfoProto_BlockDevice_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
DynamicPartitionsDeviceInfoProto_BlockDevice::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&DynamicPartitionsDeviceInfoProto_BlockDevice_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(DynamicPartitionsDeviceInfoProto_BlockDevice_class_data_.tc_table);
  return DynamicPartitionsDeviceInfoProto_BlockDevice_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
DynamicPartitionsDeviceInfoProto_BlockDevice::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&DynamicPartitionsDeviceInfoProto_BlockDevice_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&DynamicPartitionsDeviceInfoProto_BlockDevice_globals_));
  return DynamicPartitionsDeviceInfoProto_BlockDevice_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const DynamicPartitionsDeviceInfoProto_BlockDevice::ParseTableT_
    DynamicPartitionsDeviceInfoProto_BlockDevice::_table_ =
        DynamicPartitionsDeviceInfoProto_BlockDevice::InternalGenerateParseTable_(DynamicPartitionsDeviceInfoProto_BlockDevice_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void DynamicPartitionsDeviceInfoProto_BlockDevice::Clear() {
// @@protoc_insertion_point(message_clear_start:android.DynamicPartitionsDeviceInfoProto.BlockDevice)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    _impl_.name_.ClearNonDefaultToEmpty();
  }
  if (BatchCheckHasBit(cached_has_bits, 0x0000001eU)) {
    ::memset(&_impl_.size_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.alignment_offset_) -
        reinterpret_cast<char*>(&_impl_.size_)) + sizeof(_impl_.alignment_offset_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL DynamicPartitionsDeviceInfoProto_BlockDevice::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const DynamicPartitionsDeviceInfoProto_BlockDevice& this_ = static_cast<const DynamicPartitionsDeviceInfoProto_BlockDevice&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL DynamicPartitionsDeviceInfoProto_BlockDevice::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const DynamicPartitionsDeviceInfoProto_BlockDevice& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:android.DynamicPartitionsDeviceInfoProto.BlockDevice)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // string name = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_name().empty()) {
      const ::std::string& _s = this_._internal_name();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "android.DynamicPartitionsDeviceInfoProto.BlockDevice.name");
      target = stream->WriteStringMaybeAliased(1, _s, target);
    }
  }

  // uint64 size = 2;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    if (this_._internal_size() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          2, this_._internal_size(), target);
    }
  }

  // uint64 block_size = 3 [json_name = "block_size"];
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    if (this_._internal_block_size() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          3, this_._internal_block_size(), target);
    }
  }

  // uint64 alignment = 4;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    if (this_._internal_alignment() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          4, this_._internal_alignment(), target);
    }
  }

  // uint64 alignment_offset = 5 [json_name = "alignment_offset"];
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    if (this_._internal_alignment_offset() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          5, this_._internal_alignment_offset(), target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:android.DynamicPartitionsDeviceInfoProto.BlockDevice)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t DynamicPartitionsDeviceInfoProto_BlockDevice::ByteSizeLong(const MessageLite& base) {
  const DynamicPartitionsDeviceInfoProto_BlockDevice& this_ = static_cast<const DynamicPartitionsDeviceInfoProto_BlockDevice&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t DynamicPartitionsDeviceInfoProto_BlockDevice::ByteSizeLong() const {
  const DynamicPartitionsDeviceInfoProto_BlockDevice& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:android.DynamicPartitionsDeviceInfoProto.BlockDevice)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000001fU)) {
    // string name = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!this_._internal_name().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_name());
      }
    }
    // uint64 size = 2;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (this_._internal_size() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_size());
      }
    }
    // uint64 block_size = 3 [json_name = "block_size"];
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (this_._internal_block_size() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_block_size());
      }
    }
    // uint64 alignment = 4;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (this_._internal_alignment() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_alignment());
      }
    }
    // uint64 alignment_offset = 5 [json_name = "alignment_offset"];
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (this_._internal_alignment_offset() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_alignment_offset());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void DynamicPartitionsDeviceInfoProto_BlockDevice::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<DynamicPartitionsDeviceInfoProto_BlockDevice*>(&to_msg);
  auto& from = static_cast<const DynamicPartitionsDeviceInfoProto_BlockDevice&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:android.DynamicPartitionsDeviceInfoProto.BlockDevice)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000001fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!from._internal_name().empty()) {
        _this->_internal_set_name(from._internal_name());
      } else {
        if (_this->_impl_.name_.IsDefault()) {
          _this->_internal_set_name("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (from._internal_size() != 0) {
        _this->_impl_.size_ = from._impl_.size_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (from._internal_block_size() != 0) {
        _this->_impl_.block_size_ = from._impl_.block_size_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (from._internal_alignment() != 0) {
        _this->_impl_.alignment_ = from._impl_.alignment_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (from._internal_alignment_offset() != 0) {
        _this->_impl_.alignment_offset_ = from._impl_.alignment_offset_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void DynamicPartitionsDeviceInfoProto_BlockDevice::CopyFrom(const DynamicPartitionsDeviceInfoProto_BlockDevice& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:android.DynamicPartitionsDeviceInfoProto.BlockDevice)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void DynamicPartitionsDeviceInfoProto_BlockDevice::InternalSwap(DynamicPartitionsDeviceInfoProto_BlockDevice* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.name_, &other->_impl_.name_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_BlockDevice, _impl_.alignment_offset_)
      + sizeof(DynamicPartitionsDeviceInfoProto_BlockDevice::_impl_.alignment_offset_)
      - PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_BlockDevice, _impl_.size_)>(
          reinterpret_cast<char*>(&_impl_.size_),
          reinterpret_cast<char*>(&other->_impl_.size_));
}

::google::protobuf::Metadata DynamicPartitionsDeviceInfoProto_BlockDevice::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

DynamicPartitionsDeviceInfoProto_SuperDevice::DynamicPartitionsDeviceInfoProto_SuperDevice(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, DynamicPartitionsDeviceInfoProto_SuperDevice_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:android.DynamicPartitionsDeviceInfoProto.SuperDevice)
}
PROTOBUF_NDEBUG_INLINE DynamicPartitionsDeviceInfoProto_SuperDevice::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::android::DynamicPartitionsDeviceInfoProto_SuperDevice& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        name_(arena, from.name_) {}

DynamicPartitionsDeviceInfoProto_SuperDevice::DynamicPartitionsDeviceInfoProto_SuperDevice(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const DynamicPartitionsDeviceInfoProto_SuperDevice& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, DynamicPartitionsDeviceInfoProto_SuperDevice_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  DynamicPartitionsDeviceInfoProto_SuperDevice* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, used_size_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, used_size_),
           offsetof(Impl_, total_size_) -
               offsetof(Impl_, used_size_) +
               sizeof(Impl_::total_size_));

  // @@protoc_insertion_point(copy_constructor:android.DynamicPartitionsDeviceInfoProto.SuperDevice)
}
PROTOBUF_NDEBUG_INLINE DynamicPartitionsDeviceInfoProto_SuperDevice::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        name_(arena) {}

inline void DynamicPartitionsDeviceInfoProto_SuperDevice::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, used_size_),
           0,
           offsetof(Impl_, total_size_) -
               offsetof(Impl_, used_size_) +
               sizeof(Impl_::total_size_));
}
DynamicPartitionsDeviceInfoProto_SuperDevice::~DynamicPartitionsDeviceInfoProto_SuperDevice() {
  // @@protoc_insertion_point(destructor:android.DynamicPartitionsDeviceInfoProto.SuperDevice)
  SharedDtor(*this);
}
inline void DynamicPartitionsDeviceInfoProto_SuperDevice::SharedDtor(MessageLite& self) {
  DynamicPartitionsDeviceInfoProto_SuperDevice& this_ = static_cast<DynamicPartitionsDeviceInfoProto_SuperDevice&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.name_.Destroy();
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull DynamicPartitionsDeviceInfoProto_SuperDevice_class_data_ =
        DynamicPartitionsDeviceInfoProto_SuperDevice::InternalGenerateClassData_(DynamicPartitionsDeviceInfoProto_SuperDevice_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
DynamicPartitionsDeviceInfoProto_SuperDevice::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&DynamicPartitionsDeviceInfoProto_SuperDevice_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(DynamicPartitionsDeviceInfoProto_SuperDevice_class_data_.tc_table);
  return DynamicPartitionsDeviceInfoProto_SuperDevice_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
DynamicPartitionsDeviceInfoProto_SuperDevice::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&DynamicPartitionsDeviceInfoProto_SuperDevice_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&DynamicPartitionsDeviceInfoProto_SuperDevice_globals_));
  return DynamicPartitionsDeviceInfoProto_SuperDevice_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const DynamicPartitionsDeviceInfoProto_SuperDevice::ParseTableT_
    DynamicPartitionsDeviceInfoProto_SuperDevice::_table_ =
        DynamicPartitionsDeviceInfoProto_SuperDevice::InternalGenerateParseTable_(DynamicPartitionsDeviceInfoProto_SuperDevice_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void DynamicPartitionsDeviceInfoProto_SuperDevice::Clear() {
// @@protoc_insertion_point(message_clear_start:android.DynamicPartitionsDeviceInfoProto.SuperDevice)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    _impl_.name_.ClearNonDefaultToEmpty();
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00000006U)) {
    ::memset(&_impl_.used_size_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.total_size_) -
        reinterpret_cast<char*>(&_impl_.used_size_)) + sizeof(_impl_.total_size_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL DynamicPartitionsDeviceInfoProto_SuperDevice::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const DynamicPartitionsDeviceInfoProto_SuperDevice& this_ = static_cast<const DynamicPartitionsDeviceInfoProto_SuperDevice&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL DynamicPartitionsDeviceInfoProto_SuperDevice::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const DynamicPartitionsDeviceInfoProto_SuperDevice& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:android.DynamicPartitionsDeviceInfoProto.SuperDevice)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // string name = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_name().empty()) {
      const ::std::string& _s = this_._internal_name();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "android.DynamicPartitionsDeviceInfoProto.SuperDevice.name");
      target = stream->WriteStringMaybeAliased(1, _s, target);
    }
  }

  // uint64 used_size = 2 [json_name = "used_size"];
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    if (this_._internal_used_size() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          2, this_._internal_used_size(), target);
    }
  }

  // uint64 total_size = 3 [json_name = "total_size"];
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    if (this_._internal_total_size() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          3, this_._internal_total_size(), target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:android.DynamicPartitionsDeviceInfoProto.SuperDevice)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t DynamicPartitionsDeviceInfoProto_SuperDevice::ByteSizeLong(const MessageLite& base) {
  const DynamicPartitionsDeviceInfoProto_SuperDevice& this_ = static_cast<const DynamicPartitionsDeviceInfoProto_SuperDevice&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t DynamicPartitionsDeviceInfoProto_SuperDevice::ByteSizeLong() const {
  const DynamicPartitionsDeviceInfoProto_SuperDevice& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:android.DynamicPartitionsDeviceInfoProto.SuperDevice)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    // string name = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!this_._internal_name().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_name());
      }
    }
    // uint64 used_size = 2 [json_name = "used_size"];
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (this_._internal_used_size() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_used_size());
      }
    }
    // uint64 total_size = 3 [json_name = "total_size"];
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (this_._internal_total_size() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_total_size());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void DynamicPartitionsDeviceInfoProto_SuperDevice::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<DynamicPartitionsDeviceInfoProto_SuperDevice*>(&to_msg);
  auto& from = static_cast<const DynamicPartitionsDeviceInfoProto_SuperDevice&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:android.DynamicPartitionsDeviceInfoProto.SuperDevice)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!from._internal_name().empty()) {
        _this->_internal_set_name(from._internal_name());
      } else {
        if (_this->_impl_.name_.IsDefault()) {
          _this->_internal_set_name("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (from._internal_used_size() != 0) {
        _this->_impl_.used_size_ = from._impl_.used_size_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (from._internal_total_size() != 0) {
        _this->_impl_.total_size_ = from._impl_.total_size_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void DynamicPartitionsDeviceInfoProto_SuperDevice::CopyFrom(const DynamicPartitionsDeviceInfoProto_SuperDevice& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:android.DynamicPartitionsDeviceInfoProto.SuperDevice)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void DynamicPartitionsDeviceInfoProto_SuperDevice::InternalSwap(DynamicPartitionsDeviceInfoProto_SuperDevice* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.name_, &other->_impl_.name_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_SuperDevice, _impl_.total_size_)
      + sizeof(DynamicPartitionsDeviceInfoProto_SuperDevice::_impl_.total_size_)
      - PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto_SuperDevice, _impl_.used_size_)>(
          reinterpret_cast<char*>(&_impl_.used_size_),
          reinterpret_cast<char*>(&other->_impl_.used_size_));
}

::google::protobuf::Metadata DynamicPartitionsDeviceInfoProto_SuperDevice::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

DynamicPartitionsDeviceInfoProto::DynamicPartitionsDeviceInfoProto(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, DynamicPartitionsDeviceInfoProto_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:android.DynamicPartitionsDeviceInfoProto)
}
PROTOBUF_NDEBUG_INLINE DynamicPartitionsDeviceInfoProto::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::android::DynamicPartitionsDeviceInfoProto& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        partitions_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::android::DynamicPartitionsDeviceInfoProto,
              PROTOBUF_FIELD_OFFSET(::android::DynamicPartitionsDeviceInfoProto, _impl_.partitions_)>()
          , from.partitions_
        }
        ,
        groups_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::android::DynamicPartitionsDeviceInfoProto,
              PROTOBUF_FIELD_OFFSET(::android::DynamicPartitionsDeviceInfoProto, _impl_.groups_)>()
          , from.groups_
        }
        ,
        block_devices_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::android::DynamicPartitionsDeviceInfoProto,
              PROTOBUF_FIELD_OFFSET(::android::DynamicPartitionsDeviceInfoProto, _impl_.block_devices_)>()
          , from.block_devices_
        }
     {}

DynamicPartitionsDeviceInfoProto::DynamicPartitionsDeviceInfoProto(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const DynamicPartitionsDeviceInfoProto& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, DynamicPartitionsDeviceInfoProto_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  DynamicPartitionsDeviceInfoProto* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.super_device_ = (CheckHasBit(cached_has_bits, 0x00000008U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.super_device_)
                : nullptr;
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, enabled_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, enabled_),
           offsetof(Impl_, retrofit_) -
               offsetof(Impl_, enabled_) +
               sizeof(Impl_::retrofit_));

  // @@protoc_insertion_point(copy_constructor:android.DynamicPartitionsDeviceInfoProto)
}
PROTOBUF_NDEBUG_INLINE DynamicPartitionsDeviceInfoProto::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        partitions_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::android::DynamicPartitionsDeviceInfoProto,
            PROTOBUF_FIELD_OFFSET(::android::DynamicPartitionsDeviceInfoProto, _impl_.partitions_)>()
         }
        ,
        groups_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::android::DynamicPartitionsDeviceInfoProto,
            PROTOBUF_FIELD_OFFSET(::android::DynamicPartitionsDeviceInfoProto, _impl_.groups_)>()
         }
        ,
        block_devices_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::android::DynamicPartitionsDeviceInfoProto,
            PROTOBUF_FIELD_OFFSET(::android::DynamicPartitionsDeviceInfoProto, _impl_.block_devices_)>()
         }
     {}

inline void DynamicPartitionsDeviceInfoProto::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, super_device_),
           0,
           offsetof(Impl_, retrofit_) -
               offsetof(Impl_, super_device_) +
               sizeof(Impl_::retrofit_));
}
DynamicPartitionsDeviceInfoProto::~DynamicPartitionsDeviceInfoProto() {
  // @@protoc_insertion_point(destructor:android.DynamicPartitionsDeviceInfoProto)
  SharedDtor(*this);
}
inline void DynamicPartitionsDeviceInfoProto::SharedDtor(MessageLite& self) {
  DynamicPartitionsDeviceInfoProto& this_ = static_cast<DynamicPartitionsDeviceInfoProto&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  delete this_._impl_.super_device_;
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull DynamicPartitionsDeviceInfoProto_class_data_ =
        DynamicPartitionsDeviceInfoProto::InternalGenerateClassData_(DynamicPartitionsDeviceInfoProto_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
DynamicPartitionsDeviceInfoProto::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&DynamicPartitionsDeviceInfoProto_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(DynamicPartitionsDeviceInfoProto_class_data_.tc_table);
  return DynamicPartitionsDeviceInfoProto_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
DynamicPartitionsDeviceInfoProto::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&DynamicPartitionsDeviceInfoProto_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&DynamicPartitionsDeviceInfoProto_globals_));
  return DynamicPartitionsDeviceInfoProto_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const DynamicPartitionsDeviceInfoProto::ParseTableT_
    DynamicPartitionsDeviceInfoProto::_table_ =
        DynamicPartitionsDeviceInfoProto::InternalGenerateParseTable_(DynamicPartitionsDeviceInfoProto_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void DynamicPartitionsDeviceInfoProto::Clear() {
// @@protoc_insertion_point(message_clear_start:android.DynamicPartitionsDeviceInfoProto)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000000fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.partitions_.Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _impl_.groups_.Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      _impl_.block_devices_.Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      ABSL_DCHECK(_impl_.super_device_ != nullptr);
      _impl_.super_device_->Clear();
    }
  }
  ::memset(&_impl_.enabled_, 0, static_cast<::size_t>(
      reinterpret_cast<char*>(&_impl_.retrofit_) -
      reinterpret_cast<char*>(&_impl_.enabled_)) + sizeof(_impl_.retrofit_));
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL DynamicPartitionsDeviceInfoProto::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const DynamicPartitionsDeviceInfoProto& this_ = static_cast<const DynamicPartitionsDeviceInfoProto&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL DynamicPartitionsDeviceInfoProto::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const DynamicPartitionsDeviceInfoProto& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:android.DynamicPartitionsDeviceInfoProto)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // bool enabled = 1;
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    if (this_._internal_enabled() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteBoolToArray(
          1, this_._internal_enabled(), target);
    }
  }

  // bool retrofit = 2;
  if (CheckHasBit(cached_has_bits, 0x00000020U)) {
    if (this_._internal_retrofit() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteBoolToArray(
          2, this_._internal_retrofit(), target);
    }
  }

  // repeated .android.DynamicPartitionsDeviceInfoProto.Partition partitions = 3;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    for (unsigned i = 0, n = static_cast<unsigned>(
                             this_._internal_partitions_size());
         i < n; i++) {
      const auto& repfield = this_._internal_partitions().Get(i);
      target =
          ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
              3, repfield, repfield.GetCachedSize(),
              target, stream);
    }
  }

  // repeated .android.DynamicPartitionsDeviceInfoProto.Group groups = 4;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    for (unsigned i = 0, n = static_cast<unsigned>(
                             this_._internal_groups_size());
         i < n; i++) {
      const auto& repfield = this_._internal_groups().Get(i);
      target =
          ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
              4, repfield, repfield.GetCachedSize(),
              target, stream);
    }
  }

  // repeated .android.DynamicPartitionsDeviceInfoProto.BlockDevice block_devices = 5 [json_name = "block_devices"];
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    for (unsigned i = 0, n = static_cast<unsigned>(
                             this_._internal_block_devices_size());
         i < n; i++) {
      const auto& repfield = this_._internal_block_devices().Get(i);
      target =
          ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
              5, repfield, repfield.GetCachedSize(),
              target, stream);
    }
  }

  // .android.DynamicPartitionsDeviceInfoProto.SuperDevice super_device = 6 [json_name = "super_device"];
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        6, *this_._impl_.super_device_, this_._impl_.super_device_->GetCachedSize(), target,
        stream);
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:android.DynamicPartitionsDeviceInfoProto)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t DynamicPartitionsDeviceInfoProto::ByteSizeLong(const MessageLite& base) {
  const DynamicPartitionsDeviceInfoProto& this_ = static_cast<const DynamicPartitionsDeviceInfoProto&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t DynamicPartitionsDeviceInfoProto::ByteSizeLong() const {
  const DynamicPartitionsDeviceInfoProto& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:android.DynamicPartitionsDeviceInfoProto)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000003fU)) {
    // repeated .android.DynamicPartitionsDeviceInfoProto.Partition partitions = 3;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += 1UL * this_._internal_partitions_size();
      for (const auto& msg : this_._internal_partitions()) {
        total_size += ::google::protobuf::internal::WireFormatLite::MessageSize(msg);
      }
    }
    // repeated .android.DynamicPartitionsDeviceInfoProto.Group groups = 4;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      total_size += 1UL * this_._internal_groups_size();
      for (const auto& msg : this_._internal_groups()) {
        total_size += ::google::protobuf::internal::WireFormatLite::MessageSize(msg);
      }
    }
    // repeated .android.DynamicPartitionsDeviceInfoProto.BlockDevice block_devices = 5 [json_name = "block_devices"];
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      total_size += 1UL * this_._internal_block_devices_size();
      for (const auto& msg : this_._internal_block_devices()) {
        total_size += ::google::protobuf::internal::WireFormatLite::MessageSize(msg);
      }
    }
    // .android.DynamicPartitionsDeviceInfoProto.SuperDevice super_device = 6 [json_name = "super_device"];
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.super_device_);
    }
    // bool enabled = 1;
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (this_._internal_enabled() != 0) {
        total_size += 2;
      }
    }
    // bool retrofit = 2;
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (this_._internal_retrofit() != 0) {
        total_size += 2;
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void DynamicPartitionsDeviceInfoProto::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<DynamicPartitionsDeviceInfoProto*>(&to_msg);
  auto& from = static_cast<const DynamicPartitionsDeviceInfoProto&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:android.DynamicPartitionsDeviceInfoProto)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000003fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _this->_internal_mutable_partitions()->InternalMergeFromWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), arena,
          from._internal_partitions());
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _this->_internal_mutable_groups()->InternalMergeFromWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), arena,
          from._internal_groups());
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      _this->_internal_mutable_block_devices()->InternalMergeFromWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), arena,
          from._internal_block_devices());
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      ABSL_DCHECK(from._impl_.super_device_ != nullptr);
      if (_this->_impl_.super_device_ == nullptr) {
        _this->_impl_.super_device_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.super_device_);
      } else {
        _this->_impl_.super_device_->MergeFrom(*from._impl_.super_device_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (from._internal_enabled() != 0) {
        _this->_impl_.enabled_ = from._impl_.enabled_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (from._internal_retrofit() != 0) {
        _this->_impl_.retrofit_ = from._impl_.retrofit_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void DynamicPartitionsDeviceInfoProto::CopyFrom(const DynamicPartitionsDeviceInfoProto& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:android.DynamicPartitionsDeviceInfoProto)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void DynamicPartitionsDeviceInfoProto::InternalSwap(DynamicPartitionsDeviceInfoProto* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  _impl_.partitions_.InternalSwap(&other->_impl_.partitions_);
  _impl_.groups_.InternalSwap(&other->_impl_.groups_);
  _impl_.block_devices_.InternalSwap(&other->_impl_.block_devices_);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto, _impl_.retrofit_)
      + sizeof(DynamicPartitionsDeviceInfoProto::_impl_.retrofit_)
      - PROTOBUF_FIELD_OFFSET(DynamicPartitionsDeviceInfoProto, _impl_.super_device_)>(
          reinterpret_cast<char*>(&_impl_.super_device_),
          reinterpret_cast<char*>(&other->_impl_.super_device_));
}

::google::protobuf::Metadata DynamicPartitionsDeviceInfoProto::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// @@protoc_insertion_point(namespace_scope)
}  // namespace android
namespace google {
namespace protobuf {
}  // namespace protobuf
}  // namespace google
// @@protoc_insertion_point(global_scope)
PROTOBUF_ATTRIBUTE_INIT_PRIORITY2 static ::std::false_type
    _static_init2_ [[maybe_unused]] =
        (::_pbi::AddDescriptors(&descriptor_table_dynamic_5fpartitions_5fdevice_5finfo_2eproto),
         ::std::false_type{});
#include "google/protobuf/port_undef.inc"
